# @!visibility private
class postfix::config {

  $conf_dir = $::postfix::conf_dir

  $main_cf   = "${conf_dir}/main.cf"
  $master_cf = "${conf_dir}/master.cf"

  file { $main_cf:
    ensure => file,
    owner  => 0,
    group  => 0,
    mode   => '0644',
  }

  file { $master_cf:
    ensure => file,
    owner  => 0,
    group  => 0,
    mode   => '0644',
  }

  Postfix_main {
    target => $main_cf,
  }

  Postfix_master {
    target => $master_cf,
  }

  resources { 'postfix_main':
    purge => true,
  }

  resources { 'postfix_master':
    purge => true,
  }

  $config = delete_undef_values({
    '2bounce_notice_recipient'                               => $::postfix::twobounce_notice_recipient,
    'access_map_defer_code'                                  => $::postfix::access_map_defer_code,
    'access_map_reject_code'                                 => $::postfix::access_map_reject_code,
    'address_verify_cache_cleanup_interval'                  => $::postfix::address_verify_cache_cleanup_interval,
    'address_verify_default_transport'                       => $::postfix::address_verify_default_transport,
    'address_verify_local_transport'                         => $::postfix::address_verify_local_transport,
    'address_verify_map'                                     => $::postfix::address_verify_map,
    'address_verify_negative_cache'                          => $::postfix::address_verify_negative_cache ? {
      undef   => undef,
      false   => 'no',
      true    => 'yes',
      default => $::postfix::address_verify_negative_cache,
    },
    'address_verify_negative_expire_time'                    => $::postfix::address_verify_negative_expire_time,
    'address_verify_negative_refresh_time'                   => $::postfix::address_verify_negative_refresh_time,
    'address_verify_poll_count'                              => $::postfix::address_verify_poll_count,
    'address_verify_poll_delay'                              => $::postfix::address_verify_poll_delay,
    'address_verify_positive_expire_time'                    => $::postfix::address_verify_positive_expire_time,
    'address_verify_positive_refresh_time'                   => $::postfix::address_verify_positive_refresh_time,
    'address_verify_relay_transport'                         => $::postfix::address_verify_relay_transport,
    'address_verify_relayhost'                               => $::postfix::address_verify_relayhost,
    'address_verify_sender'                                  => $::postfix::address_verify_sender,
    'address_verify_sender_dependent_default_transport_maps' => $::postfix::address_verify_sender_dependent_default_transport_maps ? {
      undef   => undef,
      default => join($::postfix::address_verify_sender_dependent_default_transport_maps, ', '),
    },
    'address_verify_sender_dependent_relayhost_maps'         => $::postfix::address_verify_sender_dependent_relayhost_maps ? {
      undef   => undef,
      default => join($::postfix::address_verify_sender_dependent_relayhost_maps, ', '),
    },
    'address_verify_sender_ttl'                              => $::postfix::address_verify_sender_ttl,
    'address_verify_service_name'                            => $::postfix::address_verify_service_name,
    'address_verify_transport_maps'                          => $::postfix::address_verify_transport_maps ? {
      undef   => undef,
      default => join($::postfix::address_verify_transport_maps, ', '),
    },
    'address_verify_virtual_transport'                       => $::postfix::address_verify_virtual_transport,
    'alias_database'                                         => $::postfix::alias_database ? {
      undef   => undef,
      default => join($::postfix::alias_database, ', '),
    },
    'alias_maps'                                             => $::postfix::alias_maps ? {
      undef   => undef,
      default => join($::postfix::alias_maps, ', '),
    },
    'allow_mail_to_commands'                                 => $::postfix::allow_mail_to_commands ? {
      undef   => undef,
      default => join($::postfix::allow_mail_to_commands, ', '),
    },
    'allow_mail_to_files'                                    => $::postfix::allow_mail_to_files ? {
      undef   => undef,
      default => join($::postfix::allow_mail_to_files, ', '),
    },
    'allow_min_user'                                         => $::postfix::allow_min_user ? {
      undef   => undef,
      false   => 'no',
      true    => 'yes',
      default => $::postfix::allow_min_user,
    },
    'allow_percent_hack'                                     => $::postfix::allow_percent_hack ? {
      undef   => undef,
      false   => 'no',
      true    => 'yes',
      default => $::postfix::allow_percent_hack,
    },
    'allow_untrusted_routing'                                => $::postfix::allow_untrusted_routing ? {
      undef   => undef,
      false   => 'no',
      true    => 'yes',
      default => $::postfix::allow_untrusted_routing,
    },
    'alternate_config_directories'                           => $::postfix::alternate_config_directories ? {
      undef   => undef,
      default => join($::postfix::alternate_config_directories, ', '),
    },
    'always_add_missing_headers'                             => $::postfix::always_add_missing_headers ? {
      undef   => undef,
      false   => 'no',
      true    => 'yes',
      default => $::postfix::always_add_missing_headers,
    },
    'always_bcc'                                             => $::postfix::always_bcc,
    'anvil_rate_time_unit'                                   => $::postfix::anvil_rate_time_unit,
    'anvil_status_update_time'                               => $::postfix::anvil_status_update_time,
    'append_at_myorigin'                                     => $::postfix::append_at_myorigin ? {
      undef   => undef,
      false   => 'no',
      true    => 'yes',
      default => $::postfix::append_at_myorigin,
    },
    'append_dot_mydomain'                                    => $::postfix::append_dot_mydomain ? {
      undef   => undef,
      false   => 'no',
      true    => 'yes',
      default => $::postfix::append_dot_mydomain,
    },
    'application_event_drain_time'                           => $::postfix::application_event_drain_time,
    'authorized_flush_users'                                 => $::postfix::authorized_flush_users ? {
      undef   => undef,
      default => join($::postfix::authorized_flush_users, ', '),
    },
    'authorized_mailq_users'                                 => $::postfix::authorized_mailq_users ? {
      undef   => undef,
      default => join($::postfix::authorized_mailq_users, ', '),
    },
    'authorized_submit_users'                                => $::postfix::authorized_submit_users ? {
      undef   => undef,
      default => join($::postfix::authorized_submit_users, ', '),
    },
    'backwards_bounce_logfile_compatibility'                 => $::postfix::backwards_bounce_logfile_compatibility ? {
      undef   => undef,
      false   => 'no',
      true    => 'yes',
      default => $::postfix::backwards_bounce_logfile_compatibility,
    },
    'berkeley_db_create_buffer_size'                         => $::postfix::berkeley_db_create_buffer_size,
    'berkeley_db_read_buffer_size'                           => $::postfix::berkeley_db_read_buffer_size,
    'best_mx_transport'                                      => $::postfix::best_mx_transport,
    'biff'                                                   => $::postfix::biff ? {
      undef   => undef,
      false   => 'no',
      true    => 'yes',
      default => $::postfix::biff,
    },
    'body_checks'                                            => $::postfix::body_checks ? {
      undef   => undef,
      default => join($::postfix::body_checks, ', '),
    },
    'body_checks_size_limit'                                 => $::postfix::body_checks_size_limit,
    'bounce_notice_recipient'                                => $::postfix::bounce_notice_recipient,
    'bounce_queue_lifetime'                                  => $::postfix::bounce_queue_lifetime,
    'bounce_service_name'                                    => $::postfix::bounce_service_name,
    'bounce_size_limit'                                      => $::postfix::bounce_size_limit,
    'bounce_template_file'                                   => $::postfix::bounce_template_file,
    'broken_sasl_auth_clients'                               => $::postfix::broken_sasl_auth_clients ? {
      undef   => undef,
      false   => 'no',
      true    => 'yes',
      default => $::postfix::broken_sasl_auth_clients,
    },
    'canonical_classes'                                      => $::postfix::canonical_classes ? {
      undef   => undef,
      default => join($::postfix::canonical_classes, ', '),
    },
    'canonical_maps'                                         => $::postfix::canonical_maps ? {
      undef   => undef,
      default => join($::postfix::canonical_maps, ', '),
    },
    'cleanup_service_name'                                   => $::postfix::cleanup_service_name,
    'command_directory'                                      => $::postfix::command_directory,
    'command_execution_directory'                            => $::postfix::command_execution_directory,
    'command_expansion_filter'                               => $::postfix::command_expansion_filter,
    'command_time_limit'                                     => $::postfix::command_time_limit,
    'config_directory'                                       => $::postfix::config_directory,
    'connection_cache_protocol_timeout'                      => $::postfix::connection_cache_protocol_timeout,
    'connection_cache_service_name'                          => $::postfix::connection_cache_service_name,
    'connection_cache_status_update_time'                    => $::postfix::connection_cache_status_update_time,
    'connection_cache_ttl_limit'                             => $::postfix::connection_cache_ttl_limit,
    'content_filter'                                         => $::postfix::content_filter,
    'cyrus_sasl_config_path'                                 => $::postfix::cyrus_sasl_config_path ? {
      undef   => undef,
      default => join($::postfix::cyrus_sasl_config_path, ':'),
    },
    'daemon_directory'                                       => $::postfix::daemon_directory,
    'daemon_table_open_error_is_fatal'                       => $::postfix::daemon_table_open_error_is_fatal ? {
      undef   => undef,
      false   => 'no',
      true    => 'yes',
      default => $::postfix::daemon_table_open_error_is_fatal,
    },
    'daemon_timeout'                                         => $::postfix::daemon_timeout,
    'data_directory'                                         => $::postfix::data_directory,
    'debug_peer_level'                                       => $::postfix::debug_peer_level,
    'debug_peer_list'                                        => $::postfix::debug_peer_list ? {
      undef   => undef,
      default => join($::postfix::debug_peer_list, ', '),
    },
    'debugger_command'                                       => $::postfix::debugger_command,
    'default_database_type'                                  => $::postfix::default_database_type,
    'default_delivery_slot_cost'                             => $::postfix::default_delivery_slot_cost,
    'default_delivery_slot_discount'                         => $::postfix::default_delivery_slot_discount,
    'default_delivery_slot_loan'                             => $::postfix::default_delivery_slot_loan,
    'default_destination_concurrency_failed_cohort_limit'    => $::postfix::default_destination_concurrency_failed_cohort_limit,
    'default_destination_concurrency_limit'                  => $::postfix::default_destination_concurrency_limit,
    'default_destination_concurrency_negative_feedback'      => $::postfix::default_destination_concurrency_negative_feedback,
    'default_destination_concurrency_positive_feedback'      => $::postfix::default_destination_concurrency_positive_feedback,
    'default_destination_rate_delay'                         => $::postfix::default_destination_rate_delay,
    'default_destination_recipient_limit'                    => $::postfix::default_destination_recipient_limit,
    'default_extra_recipient_limit'                          => $::postfix::default_extra_recipient_limit,
    'default_filter_nexthop'                                 => $::postfix::default_filter_nexthop,
    'default_minimum_delivery_slots'                         => $::postfix::default_minimum_delivery_slots,
    'default_privs'                                          => $::postfix::default_privs,
    'default_process_limit'                                  => $::postfix::default_process_limit,
    'default_rbl_reply'                                      => $::postfix::default_rbl_reply,
    'default_recipient_limit'                                => $::postfix::default_recipient_limit,
    'default_recipient_refill_delay'                         => $::postfix::default_recipient_refill_delay,
    'default_recipient_refill_limit'                         => $::postfix::default_recipient_refill_limit,
    'default_transport'                                      => $::postfix::default_transport,
    'default_verp_delimiters'                                => $::postfix::default_verp_delimiters,
    'defer_code'                                             => $::postfix::defer_code,
    'defer_service_name'                                     => $::postfix::defer_service_name,
    'defer_transports'                                       => $::postfix::defer_transports ? {
      undef   => undef,
      default => join($::postfix::defer_transports, ', '),
    },
    'delay_logging_resolution_limit'                         => $::postfix::delay_logging_resolution_limit,
    'delay_notice_recipient'                                 => $::postfix::delay_notice_recipient,
    'delay_warning_time'                                     => $::postfix::delay_warning_time,
    'deliver_lock_attempts'                                  => $::postfix::deliver_lock_attempts,
    'deliver_lock_delay'                                     => $::postfix::deliver_lock_delay,
    'destination_concurrency_feedback_debug'                 => $::postfix::destination_concurrency_feedback_debug ? {
      undef   => undef,
      false   => 'no',
      true    => 'yes',
      default => $::postfix::destination_concurrency_feedback_debug,
    },
    'detect_8bit_encoding_header'                            => $::postfix::detect_8bit_encoding_header ? {
      undef   => undef,
      false   => 'no',
      true    => 'yes',
      default => $::postfix::detect_8bit_encoding_header,
    },
    'disable_dns_lookups'                                    => $::postfix::disable_dns_lookups ? {
      undef   => undef,
      false   => 'no',
      true    => 'yes',
      default => $::postfix::disable_dns_lookups,
    },
    'disable_mime_input_processing'                          => $::postfix::disable_mime_input_processing ? {
      undef   => undef,
      false   => 'no',
      true    => 'yes',
      default => $::postfix::disable_mime_input_processing,
    },
    'disable_mime_output_conversion'                         => $::postfix::disable_mime_output_conversion ? {
      undef   => undef,
      false   => 'no',
      true    => 'yes',
      default => $::postfix::disable_mime_output_conversion,
    },
    'disable_verp_bounces'                                   => $::postfix::disable_verp_bounces ? {
      undef   => undef,
      false   => 'no',
      true    => 'yes',
      default => $::postfix::disable_verp_bounces,
    },
    'disable_vrfy_command'                                   => $::postfix::disable_vrfy_command ? {
      undef   => undef,
      false   => 'no',
      true    => 'yes',
      default => $::postfix::disable_vrfy_command,
    },
    'dnsblog_reply_delay'                                    => $::postfix::dnsblog_reply_delay,
    'dnsblog_service_name'                                   => $::postfix::dnsblog_service_name,
    'dont_remove'                                            => $::postfix::dont_remove,
    'double_bounce_sender'                                   => $::postfix::double_bounce_sender,
    'duplicate_filter_limit'                                 => $::postfix::duplicate_filter_limit,
    'empty_address_default_transport_maps_lookup_key'        => $::postfix::empty_address_default_transport_maps_lookup_key,
    'empty_address_recipient'                                => $::postfix::empty_address_recipient,
    'empty_address_relayhost_maps_lookup_key'                => $::postfix::empty_address_relayhost_maps_lookup_key,
    'enable_long_queue_ids'                                  => $::postfix::enable_long_queue_ids ? {
      undef   => undef,
      false   => 'no',
      true    => 'yes',
      default => $::postfix::enable_long_queue_ids,
    },
    'enable_original_recipient'                              => $::postfix::enable_original_recipient ? {
      undef   => undef,
      false   => 'no',
      true    => 'yes',
      default => $::postfix::enable_original_recipient,
    },
    'error_notice_recipient'                                 => $::postfix::error_notice_recipient,
    'error_service_name'                                     => $::postfix::error_service_name,
    'execution_directory_expansion_filter'                   => $::postfix::execution_directory_expansion_filter,
    'expand_owner_alias'                                     => $::postfix::expand_owner_alias ? {
      undef   => undef,
      false   => 'no',
      true    => 'yes',
      default => $::postfix::expand_owner_alias,
    },
    'export_environment'                                     => $::postfix::export_environment ? {
      undef   => undef,
      default => join($::postfix::export_environment, ', '),
    },
    'fallback_transport'                                     => $::postfix::fallback_transport,
    'fallback_transport_maps'                                => $::postfix::fallback_transport_maps ? {
      undef   => undef,
      default => join($::postfix::fallback_transport_maps, ', '),
    },
    'fast_flush_domains'                                     => $::postfix::fast_flush_domains ? {
      undef   => undef,
      default => join($::postfix::fast_flush_domains, ', '),
    },
    'fast_flush_purge_time'                                  => $::postfix::fast_flush_purge_time,
    'fast_flush_refresh_time'                                => $::postfix::fast_flush_refresh_time,
    'fault_injection_code'                                   => $::postfix::fault_injection_code,
    'flush_service_name'                                     => $::postfix::flush_service_name,
    'fork_attempts'                                          => $::postfix::fork_attempts,
    'fork_delay'                                             => $::postfix::fork_delay,
    'forward_expansion_filter'                               => $::postfix::forward_expansion_filter,
    'forward_path'                                           => $::postfix::forward_path ? {
      undef   => undef,
      default => join($::postfix::forward_path, ', '),
    },
    'frozen_delivered_to'                                    => $::postfix::frozen_delivered_to ? {
      undef   => undef,
      false   => 'no',
      true    => 'yes',
      default => $::postfix::frozen_delivered_to,
    },
    'hash_queue_depth'                                       => $::postfix::hash_queue_depth,
    'hash_queue_names'                                       => $::postfix::hash_queue_names ? {
      undef   => undef,
      default => join($::postfix::hash_queue_names, ', '),
    },
    'header_address_token_limit'                             => $::postfix::header_address_token_limit,
    'header_checks'                                          => $::postfix::header_checks ? {
      undef   => undef,
      default => join($::postfix::header_checks, ', '),
    },
    'header_size_limit'                                      => $::postfix::header_size_limit,
    'helpful_warnings'                                       => $::postfix::helpful_warnings ? {
      undef   => undef,
      false   => 'no',
      true    => 'yes',
      default => $::postfix::helpful_warnings,
    },
    'home_mailbox'                                           => $::postfix::home_mailbox,
    'hopcount_limit'                                         => $::postfix::hopcount_limit,
    'html_directory'                                         => $::postfix::html_directory ? {
      undef   => undef,
      false   => 'no',
      true    => 'yes',
      default => $::postfix::html_directory,
    },
    'ignore_mx_lookup_error'                                 => $::postfix::ignore_mx_lookup_error ? {
      undef   => undef,
      false   => 'no',
      true    => 'yes',
      default => $::postfix::ignore_mx_lookup_error,
    },
    'import_environment'                                     => $::postfix::import_environment ? {
      undef   => undef,
      default => join($::postfix::import_environment, ', '),
    },
    'in_flow_delay'                                          => $::postfix::in_flow_delay,
    'inet_interfaces'                                        => $::postfix::inet_interfaces ? {
      undef   => undef,
      default => join($::postfix::inet_interfaces, ', '),
    },
    'inet_protocols'                                         => $::postfix::inet_protocols ? {
      undef   => undef,
      default => join($::postfix::inet_protocols, ', '),
    },
    'initial_destination_concurrency'                        => $::postfix::initial_destination_concurrency,
    'internal_mail_filter_classes'                           => $::postfix::internal_mail_filter_classes ? {
      undef   => undef,
      default => join($::postfix::internal_mail_filter_classes, ', '),
    },
    'invalid_hostname_reject_code'                           => $::postfix::invalid_hostname_reject_code,
    'ipc_idle'                                               => $::postfix::ipc_idle,
    'ipc_timeout'                                            => $::postfix::ipc_timeout,
    'ipc_ttl'                                                => $::postfix::ipc_ttl,
    'line_length_limit'                                      => $::postfix::line_length_limit,
    'lmtp_address_preference'                                => $::postfix::lmtp_address_preference,
    'lmtp_assume_final'                                      => $::postfix::lmtp_assume_final ? {
      undef   => undef,
      false   => 'no',
      true    => 'yes',
      default => $::postfix::lmtp_assume_final,
    },
    'lmtp_bind_address'                                      => $::postfix::lmtp_bind_address,
    'lmtp_bind_address6'                                     => $::postfix::lmtp_bind_address6,
    'lmtp_body_checks'                                       => $::postfix::lmtp_body_checks ? {
      undef   => undef,
      default => join($::postfix::lmtp_body_checks, ', '),
    },
    'lmtp_cname_overrides_servername'                        => $::postfix::lmtp_cname_overrides_servername ? {
      undef   => undef,
      false   => 'no',
      true    => 'yes',
      default => $::postfix::lmtp_cname_overrides_servername,
    },
    'lmtp_connect_timeout'                                   => $::postfix::lmtp_connect_timeout,
    'lmtp_connection_cache_destinations'                     => $::postfix::lmtp_connection_cache_destinations ? {
      undef   => undef,
      default => join($::postfix::lmtp_connection_cache_destinations, ', '),
    },
    'lmtp_connection_cache_on_demand'                        => $::postfix::lmtp_connection_cache_on_demand ? {
      undef   => undef,
      false   => 'no',
      true    => 'yes',
      default => $::postfix::lmtp_connection_cache_on_demand,
    },
    'lmtp_connection_cache_time_limit'                       => $::postfix::lmtp_connection_cache_time_limit,
    'lmtp_connection_reuse_time_limit'                       => $::postfix::lmtp_connection_reuse_time_limit,
    'lmtp_data_done_timeout'                                 => $::postfix::lmtp_data_done_timeout,
    'lmtp_data_init_timeout'                                 => $::postfix::lmtp_data_init_timeout,
    'lmtp_data_xfer_timeout'                                 => $::postfix::lmtp_data_xfer_timeout,
    'lmtp_defer_if_no_mx_address_found'                      => $::postfix::lmtp_defer_if_no_mx_address_found ? {
      undef   => undef,
      false   => 'no',
      true    => 'yes',
      default => $::postfix::lmtp_defer_if_no_mx_address_found,
    },
    'lmtp_discard_lhlo_keyword_address_maps'                 => $::postfix::lmtp_discard_lhlo_keyword_address_maps ? {
      undef   => undef,
      default => join($::postfix::lmtp_discard_lhlo_keyword_address_maps, ', '),
    },
    'lmtp_discard_lhlo_keywords'                             => $::postfix::lmtp_discard_lhlo_keywords ? {
      undef   => undef,
      default => join($::postfix::lmtp_discard_lhlo_keywords, ', '),
    },
    'lmtp_dns_resolver_options'                              => $::postfix::lmtp_dns_resolver_options ? {
      undef   => undef,
      default => join($::postfix::lmtp_dns_resolver_options, ', '),
    },
    'lmtp_enforce_tls'                                       => $::postfix::lmtp_enforce_tls ? {
      undef   => undef,
      false   => 'no',
      true    => 'yes',
      default => $::postfix::lmtp_enforce_tls,
    },
    'lmtp_generic_maps'                                      => $::postfix::lmtp_generic_maps ? {
      undef   => undef,
      default => join($::postfix::lmtp_generic_maps, ', '),
    },
    'lmtp_header_checks'                                     => $::postfix::lmtp_header_checks ? {
      undef   => undef,
      default => join($::postfix::lmtp_header_checks, ', '),
    },
    'lmtp_host_lookup'                                       => $::postfix::lmtp_host_lookup ? {
      undef   => undef,
      default => join($::postfix::lmtp_host_lookup, ', '),
    },
    'lmtp_lhlo_name'                                         => $::postfix::lmtp_lhlo_name,
    'lmtp_lhlo_timeout'                                      => $::postfix::lmtp_lhlo_timeout,
    'lmtp_line_length_limit'                                 => $::postfix::lmtp_line_length_limit,
    'lmtp_mail_timeout'                                      => $::postfix::lmtp_mail_timeout,
    'lmtp_mime_header_checks'                                => $::postfix::lmtp_mime_header_checks ? {
      undef   => undef,
      default => join($::postfix::lmtp_mime_header_checks, ', '),
    },
    'lmtp_mx_address_limit'                                  => $::postfix::lmtp_mx_address_limit,
    'lmtp_mx_session_limit'                                  => $::postfix::lmtp_mx_session_limit,
    'lmtp_nested_header_checks'                              => $::postfix::lmtp_nested_header_checks ? {
      undef   => undef,
      default => join($::postfix::lmtp_nested_header_checks, ', '),
    },
    'lmtp_per_record_deadline'                               => $::postfix::lmtp_per_record_deadline ? {
      undef   => undef,
      false   => 'no',
      true    => 'yes',
      default => $::postfix::lmtp_per_record_deadline,
    },
    'lmtp_pix_workaround_delay_time'                         => $::postfix::lmtp_pix_workaround_delay_time,
    'lmtp_pix_workaround_maps'                               => $::postfix::lmtp_pix_workaround_maps ? {
      undef   => undef,
      default => join($::postfix::lmtp_pix_workaround_maps, ', '),
    },
    'lmtp_pix_workaround_threshold_time'                     => $::postfix::lmtp_pix_workaround_threshold_time,
    'lmtp_pix_workarounds'                                   => $::postfix::lmtp_pix_workarounds ? {
      undef   => undef,
      default => join($::postfix::lmtp_pix_workarounds, ', '),
    },
    'lmtp_quit_timeout'                                      => $::postfix::lmtp_quit_timeout,
    'lmtp_quote_rfc821_envelope'                             => $::postfix::lmtp_quote_rfc821_envelope ? {
      undef   => undef,
      false   => 'no',
      true    => 'yes',
      default => $::postfix::lmtp_quote_rfc821_envelope,
    },
    'lmtp_randomize_addresses'                               => $::postfix::lmtp_randomize_addresses ? {
      undef   => undef,
      false   => 'no',
      true    => 'yes',
      default => $::postfix::lmtp_randomize_addresses,
    },
    'lmtp_rcpt_timeout'                                      => $::postfix::lmtp_rcpt_timeout,
    'lmtp_reply_filter'                                      => $::postfix::lmtp_reply_filter,
    'lmtp_rset_timeout'                                      => $::postfix::lmtp_rset_timeout,
    'lmtp_sasl_auth_cache_name'                              => $::postfix::lmtp_sasl_auth_cache_name,
    'lmtp_sasl_auth_cache_time'                              => $::postfix::lmtp_sasl_auth_cache_time,
    'lmtp_sasl_auth_enable'                                  => $::postfix::lmtp_sasl_auth_enable ? {
      undef   => undef,
      false   => 'no',
      true    => 'yes',
      default => $::postfix::lmtp_sasl_auth_enable,
    },
    'lmtp_sasl_auth_soft_bounce'                             => $::postfix::lmtp_sasl_auth_soft_bounce ? {
      undef   => undef,
      false   => 'no',
      true    => 'yes',
      default => $::postfix::lmtp_sasl_auth_soft_bounce,
    },
    'lmtp_sasl_mechanism_filter'                             => $::postfix::lmtp_sasl_mechanism_filter ? {
      undef   => undef,
      default => join($::postfix::lmtp_sasl_mechanism_filter, ', '),
    },
    'lmtp_sasl_password_maps'                                => $::postfix::lmtp_sasl_password_maps ? {
      undef   => undef,
      default => join($::postfix::lmtp_sasl_password_maps, ', '),
    },
    'lmtp_sasl_path'                                         => $::postfix::lmtp_sasl_path,
    'lmtp_sasl_security_options'                             => $::postfix::lmtp_sasl_security_options ? {
      undef   => undef,
      default => join($::postfix::lmtp_sasl_security_options, ', '),
    },
    'lmtp_sasl_tls_security_options'                         => $::postfix::lmtp_sasl_tls_security_options ? {
      undef   => undef,
      default => join($::postfix::lmtp_sasl_tls_security_options, ', '),
    },
    'lmtp_sasl_tls_verified_security_options'                => $::postfix::lmtp_sasl_tls_verified_security_options ? {
      undef   => undef,
      default => join($::postfix::lmtp_sasl_tls_verified_security_options, ', '),
    },
    'lmtp_sasl_type'                                         => $::postfix::lmtp_sasl_type,
    'lmtp_send_dummy_mail_auth'                              => $::postfix::lmtp_send_dummy_mail_auth ? {
      undef   => undef,
      false   => 'no',
      true    => 'yes',
      default => $::postfix::lmtp_send_dummy_mail_auth,
    },
    'lmtp_send_xforward_command'                             => $::postfix::lmtp_send_xforward_command ? {
      undef   => undef,
      false   => 'no',
      true    => 'yes',
      default => $::postfix::lmtp_send_xforward_command,
    },
    'lmtp_sender_dependent_authentication'                   => $::postfix::lmtp_sender_dependent_authentication ? {
      undef   => undef,
      false   => 'no',
      true    => 'yes',
      default => $::postfix::lmtp_sender_dependent_authentication,
    },
    'lmtp_skip_5xx_greeting'                                 => $::postfix::lmtp_skip_5xx_greeting ? {
      undef   => undef,
      false   => 'no',
      true    => 'yes',
      default => $::postfix::lmtp_skip_5xx_greeting,
    },
    'lmtp_skip_quit_response'                                => $::postfix::lmtp_skip_quit_response ? {
      undef   => undef,
      false   => 'no',
      true    => 'yes',
      default => $::postfix::lmtp_skip_quit_response,
    },
    'lmtp_starttls_timeout'                                  => $::postfix::lmtp_starttls_timeout,
    'lmtp_tcp_port'                                          => $::postfix::lmtp_tcp_port,
    'lmtp_tls_CAfile'                                        => $::postfix::lmtp_tls_cafile,
    'lmtp_tls_CApath'                                        => $::postfix::lmtp_tls_capath,
    'lmtp_tls_block_early_mail_reply'                        => $::postfix::lmtp_tls_block_early_mail_reply ? {
      undef   => undef,
      false   => 'no',
      true    => 'yes',
      default => $::postfix::lmtp_tls_block_early_mail_reply,
    },
    'lmtp_tls_cert_file'                                     => $::postfix::lmtp_tls_cert_file,
    'lmtp_tls_ciphers'                                       => $::postfix::lmtp_tls_ciphers,
    'lmtp_tls_dcert_file'                                    => $::postfix::lmtp_tls_dcert_file,
    'lmtp_tls_dkey_file'                                     => $::postfix::lmtp_tls_dkey_file,
    'lmtp_tls_eccert_file'                                   => $::postfix::lmtp_tls_eccert_file,
    'lmtp_tls_eckey_file'                                    => $::postfix::lmtp_tls_eckey_file,
    'lmtp_tls_enforce_peername'                              => $::postfix::lmtp_tls_enforce_peername ? {
      undef   => undef,
      false   => 'no',
      true    => 'yes',
      default => $::postfix::lmtp_tls_enforce_peername,
    },
    'lmtp_tls_exclude_ciphers'                               => $::postfix::lmtp_tls_exclude_ciphers ? {
      undef   => undef,
      default => join($::postfix::lmtp_tls_exclude_ciphers, ', '),
    },
    'lmtp_tls_fingerprint_cert_match'                        => $::postfix::lmtp_tls_fingerprint_cert_match ? {
      undef   => undef,
      default => join($::postfix::lmtp_tls_fingerprint_cert_match, ', '),
    },
    'lmtp_tls_fingerprint_digest'                            => $::postfix::lmtp_tls_fingerprint_digest,
    'lmtp_tls_key_file'                                      => $::postfix::lmtp_tls_key_file,
    'lmtp_tls_loglevel'                                      => $::postfix::lmtp_tls_loglevel,
    'lmtp_tls_mandatory_ciphers'                             => $::postfix::lmtp_tls_mandatory_ciphers,
    'lmtp_tls_mandatory_exclude_ciphers'                     => $::postfix::lmtp_tls_mandatory_exclude_ciphers ? {
      undef   => undef,
      default => join($::postfix::lmtp_tls_mandatory_exclude_ciphers, ', '),
    },
    'lmtp_tls_mandatory_protocols'                           => $::postfix::lmtp_tls_mandatory_protocols ? {
      undef   => undef,
      default => join($::postfix::lmtp_tls_mandatory_protocols, ', '),
    },
    'lmtp_tls_note_starttls_offer'                           => $::postfix::lmtp_tls_note_starttls_offer ? {
      undef   => undef,
      false   => 'no',
      true    => 'yes',
      default => $::postfix::lmtp_tls_note_starttls_offer,
    },
    'lmtp_tls_per_site'                                      => $::postfix::lmtp_tls_per_site ? {
      undef   => undef,
      default => join($::postfix::lmtp_tls_per_site, ', '),
    },
    'lmtp_tls_policy_maps'                                   => $::postfix::lmtp_tls_policy_maps ? {
      undef   => undef,
      default => join($::postfix::lmtp_tls_policy_maps, ', '),
    },
    'lmtp_tls_protocols'                                     => $::postfix::lmtp_tls_protocols ? {
      undef   => undef,
      default => join($::postfix::lmtp_tls_protocols, ', '),
    },
    'lmtp_tls_scert_verifydepth'                             => $::postfix::lmtp_tls_scert_verifydepth,
    'lmtp_tls_secure_cert_match'                             => $::postfix::lmtp_tls_secure_cert_match ? {
      undef   => undef,
      default => join($::postfix::lmtp_tls_secure_cert_match, ', '),
    },
    'lmtp_tls_security_level'                                => $::postfix::lmtp_tls_security_level,
    'lmtp_tls_session_cache_database'                        => $::postfix::lmtp_tls_session_cache_database,
    'lmtp_tls_session_cache_timeout'                         => $::postfix::lmtp_tls_session_cache_timeout,
    'lmtp_tls_verify_cert_match'                             => $::postfix::lmtp_tls_verify_cert_match ? {
      undef   => undef,
      default => join($::postfix::lmtp_tls_verify_cert_match, ', '),
    },
    'lmtp_use_tls'                                           => $::postfix::lmtp_use_tls ? {
      undef   => undef,
      false   => 'no',
      true    => 'yes',
      default => $::postfix::lmtp_use_tls,
    },
    'lmtp_xforward_timeout'                                  => $::postfix::lmtp_xforward_timeout,
    'local_command_shell'                                    => $::postfix::local_command_shell,
    'local_header_rewrite_clients'                           => $::postfix::local_header_rewrite_clients ? {
      undef   => undef,
      default => join($::postfix::local_header_rewrite_clients, ', '),
    },
    'local_recipient_maps'                                   => $::postfix::local_recipient_maps ? {
      undef   => undef,
      default => join($::postfix::local_recipient_maps, ', '),
    },
    'local_transport'                                        => $::postfix::local_transport,
    'luser_relay'                                            => $::postfix::luser_relay,
    'mail_name'                                              => $::postfix::mail_name,
    'mail_owner'                                             => $::postfix::mail_owner,
    'mail_release_date'                                      => $::postfix::mail_release_date,
    'mail_spool_directory'                                   => $::postfix::mail_spool_directory,
    'mail_version'                                           => $::postfix::mail_version,
    'mailbox_command'                                        => $::postfix::mailbox_command,
    'mailbox_command_maps'                                   => $::postfix::mailbox_command_maps ? {
      undef   => undef,
      default => join($::postfix::mailbox_command_maps, ', '),
    },
    'mailbox_delivery_lock'                                  => $::postfix::mailbox_delivery_lock ? {
      undef   => undef,
      default => join($::postfix::mailbox_delivery_lock, ', '),
    },
    'mailbox_size_limit'                                     => $::postfix::mailbox_size_limit,
    'mailbox_transport'                                      => $::postfix::mailbox_transport,
    'mailbox_transport_maps'                                 => $::postfix::mailbox_transport_maps ? {
      undef   => undef,
      default => join($::postfix::mailbox_transport_maps, ', '),
    },
    'mailq_path'                                             => $::postfix::mailq_path,
    'manpage_directory'                                      => $::postfix::manpage_directory,
    'maps_rbl_domains'                                       => $::postfix::maps_rbl_domains ? {
      undef   => undef,
      default => join($::postfix::maps_rbl_domains, ', '),
    },
    'maps_rbl_reject_code'                                   => $::postfix::maps_rbl_reject_code,
    'masquerade_classes'                                     => $::postfix::masquerade_classes,
    'masquerade_domains'                                     => $::postfix::masquerade_domains ? {
      undef   => undef,
      default => join($::postfix::masquerade_domains, ', '),
    },
    'masquerade_exceptions'                                  => $::postfix::masquerade_exceptions ? {
      undef   => undef,
      default => join($::postfix::masquerade_exceptions, ', '),
    },
    'master_service_disable'                                 => $::postfix::master_service_disable ? {
      undef   => undef,
      default => join($::postfix::master_service_disable, ', '),
    },
    'max_idle'                                               => $::postfix::max_idle,
    'max_use'                                                => $::postfix::max_use,
    'maximal_backoff_time'                                   => $::postfix::maximal_backoff_time,
    'maximal_queue_lifetime'                                 => $::postfix::maximal_queue_lifetime,
    'message_reject_characters'                              => $::postfix::message_reject_characters,
    'message_size_limit'                                     => $::postfix::message_size_limit,
    'message_strip_characters'                               => $::postfix::message_strip_characters,
    'milter_command_timeout'                                 => $::postfix::milter_command_timeout,
    'milter_connect_macros'                                  => $::postfix::milter_connect_macros,
    'milter_connect_timeout'                                 => $::postfix::milter_connect_timeout,
    'milter_content_timeout'                                 => $::postfix::milter_content_timeout,
    'milter_data_macros'                                     => $::postfix::milter_data_macros,
    'milter_default_action'                                  => $::postfix::milter_default_action,
    'milter_end_of_data_macros'                              => $::postfix::milter_end_of_data_macros,
    'milter_end_of_header_macros'                            => $::postfix::milter_end_of_header_macros,
    'milter_header_checks'                                   => $::postfix::milter_header_checks ? {
      undef   => undef,
      default => join($::postfix::milter_header_checks, ', '),
    },
    'milter_helo_macros'                                     => $::postfix::milter_helo_macros,
    'milter_macro_daemon_name'                               => $::postfix::milter_macro_daemon_name,
    'milter_macro_v'                                         => $::postfix::milter_macro_v,
    'milter_mail_macros'                                     => $::postfix::milter_mail_macros,
    'milter_protocol'                                        => $::postfix::milter_protocol,
    'milter_rcpt_macros'                                     => $::postfix::milter_rcpt_macros,
    'milter_unknown_command_macros'                          => $::postfix::milter_unknown_command_macros,
    'mime_boundary_length_limit'                             => $::postfix::mime_boundary_length_limit,
    'mime_header_checks'                                     => $::postfix::mime_header_checks ? {
      undef   => undef,
      default => join($::postfix::mime_header_checks, ', '),
    },
    'mime_nesting_limit'                                     => $::postfix::mime_nesting_limit,
    'minimal_backoff_time'                                   => $::postfix::minimal_backoff_time,
    'multi_instance_directories'                             => $::postfix::multi_instance_directories ? {
      undef   => undef,
      default => join($::postfix::multi_instance_directories, ', '),
    },
    'multi_instance_enable'                                  => $::postfix::multi_instance_enable ? {
      undef   => undef,
      false   => 'no',
      true    => 'yes',
      default => $::postfix::multi_instance_enable,
    },
    'multi_instance_group'                                   => $::postfix::multi_instance_group,
    'multi_instance_name'                                    => $::postfix::multi_instance_name,
    'multi_instance_wrapper'                                 => $::postfix::multi_instance_wrapper,
    'multi_recipient_bounce_reject_code'                     => $::postfix::multi_recipient_bounce_reject_code,
    'mydestination'                                          => $::postfix::mydestination ? {
      undef   => undef,
      default => join($::postfix::mydestination, ', '),
    },
    'mydomain'                                               => $::postfix::mydomain,
    'myhostname'                                             => $::postfix::myhostname,
    'mynetworks'                                             => $::postfix::mynetworks ? {
      undef   => undef,
      default => join($::postfix::mynetworks, ', '),
    },
    'mynetworks_style'                                       => $::postfix::mynetworks_style,
    'myorigin'                                               => $::postfix::myorigin,
    'nested_header_checks'                                   => $::postfix::nested_header_checks ? {
      undef   => undef,
      default => join($::postfix::nested_header_checks, ', '),
    },
    'newaliases_path'                                        => $::postfix::newaliases_path,
    'non_fqdn_reject_code'                                   => $::postfix::non_fqdn_reject_code,
    'non_smtpd_milters'                                      => $::postfix::non_smtpd_milters ? {
      undef   => undef,
      default => join($::postfix::non_smtpd_milters, ', '),
    },
    'notify_classes'                                         => $::postfix::notify_classes ? {
      undef   => undef,
      default => join($::postfix::notify_classes, ', '),
    },
    'owner_request_special'                                  => $::postfix::owner_request_special ? {
      undef   => undef,
      false   => 'no',
      true    => 'yes',
      default => $::postfix::owner_request_special,
    },
    'parent_domain_matches_subdomains'                       => $::postfix::parent_domain_matches_subdomains ? {
      undef   => undef,
      default => join($::postfix::parent_domain_matches_subdomains, ', '),
    },
    'permit_mx_backup_networks'                              => $::postfix::permit_mx_backup_networks ? {
      undef   => undef,
      default => join($::postfix::permit_mx_backup_networks, ', '),
    },
    'pickup_service_name'                                    => $::postfix::pickup_service_name,
    'plaintext_reject_code'                                  => $::postfix::plaintext_reject_code,
    'postmulti_control_commands'                             => $::postfix::postmulti_control_commands ? {
      undef   => undef,
      default => join($::postfix::postmulti_control_commands, ', '),
    },
    'postmulti_start_commands'                               => $::postfix::postmulti_start_commands ? {
      undef   => undef,
      default => join($::postfix::postmulti_start_commands, ', '),
    },
    'postmulti_stop_commands'                                => $::postfix::postmulti_stop_commands ? {
      undef   => undef,
      default => join($::postfix::postmulti_stop_commands, ', '),
    },
    'postscreen_access_list'                                 => $::postfix::postscreen_access_list ? {
      undef   => undef,
      default => join($::postfix::postscreen_access_list, ', '),
    },
    'postscreen_bare_newline_action'                         => $::postfix::postscreen_bare_newline_action,
    'postscreen_bare_newline_enable'                         => $::postfix::postscreen_bare_newline_enable ? {
      undef   => undef,
      false   => 'no',
      true    => 'yes',
      default => $::postfix::postscreen_bare_newline_enable,
    },
    'postscreen_bare_newline_ttl'                            => $::postfix::postscreen_bare_newline_ttl,
    'postscreen_blacklist_action'                            => $::postfix::postscreen_blacklist_action,
    'postscreen_cache_cleanup_interval'                      => $::postfix::postscreen_cache_cleanup_interval,
    'postscreen_cache_map'                                   => $::postfix::postscreen_cache_map,
    'postscreen_cache_retention_time'                        => $::postfix::postscreen_cache_retention_time,
    'postscreen_client_connection_count_limit'               => $::postfix::postscreen_client_connection_count_limit,
    'postscreen_command_count_limit'                         => $::postfix::postscreen_command_count_limit,
    'postscreen_command_filter'                              => $::postfix::postscreen_command_filter,
    'postscreen_command_time_limit'                          => $::postfix::postscreen_command_time_limit,
    'postscreen_disable_vrfy_command'                        => $::postfix::postscreen_disable_vrfy_command ? {
      undef   => undef,
      false   => 'no',
      true    => 'yes',
      default => $::postfix::postscreen_disable_vrfy_command,
    },
    'postscreen_discard_ehlo_keyword_address_maps'           => $::postfix::postscreen_discard_ehlo_keyword_address_maps ? {
      undef   => undef,
      default => join($::postfix::postscreen_discard_ehlo_keyword_address_maps, ', '),
    },
    'postscreen_discard_ehlo_keywords'                       => $::postfix::postscreen_discard_ehlo_keywords ? {
      undef   => undef,
      default => join($::postfix::postscreen_discard_ehlo_keywords, ', '),
    },
    'postscreen_dnsbl_action'                                => $::postfix::postscreen_dnsbl_action,
    'postscreen_dnsbl_reply_map'                             => $::postfix::postscreen_dnsbl_reply_map,
    'postscreen_dnsbl_sites'                                 => $::postfix::postscreen_dnsbl_sites ? {
      undef   => undef,
      default => join($::postfix::postscreen_dnsbl_sites, ', '),
    },
    'postscreen_dnsbl_threshold'                             => $::postfix::postscreen_dnsbl_threshold,
    'postscreen_dnsbl_ttl'                                   => $::postfix::postscreen_dnsbl_ttl,
    'postscreen_enforce_tls'                                 => $::postfix::postscreen_enforce_tls ? {
      undef   => undef,
      false   => 'no',
      true    => 'yes',
      default => $::postfix::postscreen_enforce_tls,
    },
    'postscreen_expansion_filter'                            => $::postfix::postscreen_expansion_filter,
    'postscreen_forbidden_commands'                          => $::postfix::postscreen_forbidden_commands ? {
      undef   => undef,
      default => join($::postfix::postscreen_forbidden_commands, ', '),
    },
    'postscreen_greet_action'                                => $::postfix::postscreen_greet_action,
    'postscreen_greet_banner'                                => $::postfix::postscreen_greet_banner,
    'postscreen_greet_ttl'                                   => $::postfix::postscreen_greet_ttl,
    'postscreen_greet_wait'                                  => $::postfix::postscreen_greet_wait,
    'postscreen_helo_required'                               => $::postfix::postscreen_helo_required ? {
      undef   => undef,
      false   => 'no',
      true    => 'yes',
      default => $::postfix::postscreen_helo_required,
    },
    'postscreen_non_smtp_command_action'                     => $::postfix::postscreen_non_smtp_command_action,
    'postscreen_non_smtp_command_enable'                     => $::postfix::postscreen_non_smtp_command_enable ? {
      undef   => undef,
      false   => 'no',
      true    => 'yes',
      default => $::postfix::postscreen_non_smtp_command_enable,
    },
    'postscreen_non_smtp_command_ttl'                        => $::postfix::postscreen_non_smtp_command_ttl,
    'postscreen_pipelining_action'                           => $::postfix::postscreen_pipelining_action,
    'postscreen_pipelining_enable'                           => $::postfix::postscreen_pipelining_enable ? {
      undef   => undef,
      false   => 'no',
      true    => 'yes',
      default => $::postfix::postscreen_pipelining_enable,
    },
    'postscreen_pipelining_ttl'                              => $::postfix::postscreen_pipelining_ttl,
    'postscreen_post_queue_limit'                            => $::postfix::postscreen_post_queue_limit,
    'postscreen_pre_queue_limit'                             => $::postfix::postscreen_pre_queue_limit,
    'postscreen_reject_footer'                               => $::postfix::postscreen_reject_footer,
    'postscreen_tls_security_level'                          => $::postfix::postscreen_tls_security_level,
    'postscreen_upstream_proxy_protocol'                     => $::postfix::postscreen_upstream_proxy_protocol,
    'postscreen_upstream_proxy_timeout'                      => $::postfix::postscreen_upstream_proxy_timeout,
    'postscreen_use_tls'                                     => $::postfix::postscreen_use_tls ? {
      undef   => undef,
      false   => 'no',
      true    => 'yes',
      default => $::postfix::postscreen_use_tls,
    },
    'postscreen_watchdog_timeout'                            => $::postfix::postscreen_watchdog_timeout,
    'postscreen_whitelist_interfaces'                        => $::postfix::postscreen_whitelist_interfaces ? {
      undef   => undef,
      default => join($::postfix::postscreen_whitelist_interfaces, ', '),
    },
    'prepend_delivered_header'                               => $::postfix::prepend_delivered_header ? {
      undef   => undef,
      default => join($::postfix::prepend_delivered_header, ', '),
    },
    'process_id_directory'                                   => $::postfix::process_id_directory,
    'propagate_unmatched_extensions'                         => $::postfix::propagate_unmatched_extensions ? {
      undef   => undef,
      default => join($::postfix::propagate_unmatched_extensions, ', '),
    },
    'proxy_interfaces'                                       => $::postfix::proxy_interfaces ? {
      undef   => undef,
      default => join($::postfix::proxy_interfaces, ', '),
    },
    'proxy_read_maps'                                        => $::postfix::proxy_read_maps ? {
      undef   => undef,
      default => join($::postfix::proxy_read_maps, ', '),
    },
    'proxy_write_maps'                                       => $::postfix::proxy_write_maps ? {
      undef   => undef,
      default => join($::postfix::proxy_write_maps, ', '),
    },
    'proxymap_service_name'                                  => $::postfix::proxymap_service_name,
    'proxywrite_service_name'                                => $::postfix::proxywrite_service_name,
    'qmgr_clog_warn_time'                                    => $::postfix::qmgr_clog_warn_time,
    'qmgr_daemon_timeout'                                    => $::postfix::qmgr_daemon_timeout,
    'qmgr_fudge_factor'                                      => $::postfix::qmgr_fudge_factor,
    'qmgr_ipc_timeout'                                       => $::postfix::qmgr_ipc_timeout,
    'qmgr_message_active_limit'                              => $::postfix::qmgr_message_active_limit,
    'qmgr_message_recipient_limit'                           => $::postfix::qmgr_message_recipient_limit,
    'qmgr_message_recipient_minimum'                         => $::postfix::qmgr_message_recipient_minimum,
    'qmqpd_authorized_clients'                               => $::postfix::qmqpd_authorized_clients ? {
      undef   => undef,
      default => join($::postfix::qmqpd_authorized_clients, ', '),
    },
    'qmqpd_client_port_logging'                              => $::postfix::qmqpd_client_port_logging ? {
      undef   => undef,
      false   => 'no',
      true    => 'yes',
      default => $::postfix::qmqpd_client_port_logging,
    },
    'qmqpd_error_delay'                                      => $::postfix::qmqpd_error_delay,
    'qmqpd_timeout'                                          => $::postfix::qmqpd_timeout,
    'queue_directory'                                        => $::postfix::queue_directory,
    'queue_file_attribute_count_limit'                       => $::postfix::queue_file_attribute_count_limit,
    'queue_minfree'                                          => $::postfix::queue_minfree,
    'queue_run_delay'                                        => $::postfix::queue_run_delay,
    'queue_service_name'                                     => $::postfix::queue_service_name,
    'rbl_reply_maps'                                         => $::postfix::rbl_reply_maps ? {
      undef   => undef,
      default => join($::postfix::rbl_reply_maps, ', '),
    },
    'readme_directory'                                       => $::postfix::readme_directory ? {
      undef   => undef,
      false   => 'no',
      true    => 'yes',
      default => $::postfix::readme_directory,
    },
    'receive_override_options'                               => $::postfix::receive_override_options ? {
      undef   => undef,
      default => join($::postfix::receive_override_options, ', '),
    },
    'recipient_bcc_maps'                                     => $::postfix::recipient_bcc_maps ? {
      undef   => undef,
      default => join($::postfix::recipient_bcc_maps, ', '),
    },
    'recipient_canonical_classes'                            => $::postfix::recipient_canonical_classes ? {
      undef   => undef,
      default => join($::postfix::recipient_canonical_classes, ', '),
    },
    'recipient_canonical_maps'                               => $::postfix::recipient_canonical_maps ? {
      undef   => undef,
      default => join($::postfix::recipient_canonical_maps, ', '),
    },
    'recipient_delimiter'                                    => $::postfix::recipient_delimiter,
    'reject_code'                                            => $::postfix::reject_code,
    'reject_tempfail_action'                                 => $::postfix::reject_tempfail_action,
    'relay_clientcerts'                                      => $::postfix::relay_clientcerts ? {
      undef   => undef,
      default => join($::postfix::relay_clientcerts, ', '),
    },
    'relay_domains'                                          => $::postfix::relay_domains ? {
      undef   => undef,
      default => join($::postfix::relay_domains, ', '),
    },
    'relay_domains_reject_code'                              => $::postfix::relay_domains_reject_code,
    'relay_recipient_maps'                                   => $::postfix::relay_recipient_maps ? {
      undef   => undef,
      default => join($::postfix::relay_recipient_maps, ', '),
    },
    'relay_transport'                                        => $::postfix::relay_transport,
    'relayhost'                                              => $::postfix::relayhost,
    'relocated_maps'                                         => $::postfix::relocated_maps ? {
      undef   => undef,
      default => join($::postfix::relocated_maps, ', '),
    },
    'remote_header_rewrite_domain'                           => $::postfix::remote_header_rewrite_domain,
    'require_home_directory'                                 => $::postfix::require_home_directory ? {
      undef   => undef,
      false   => 'no',
      true    => 'yes',
      default => $::postfix::require_home_directory,
    },
    'reset_owner_alias'                                      => $::postfix::reset_owner_alias ? {
      undef   => undef,
      false   => 'no',
      true    => 'yes',
      default => $::postfix::reset_owner_alias,
    },
    'resolve_dequoted_address'                               => $::postfix::resolve_dequoted_address ? {
      undef   => undef,
      false   => 'no',
      true    => 'yes',
      default => $::postfix::resolve_dequoted_address,
    },
    'resolve_null_domain'                                    => $::postfix::resolve_null_domain ? {
      undef   => undef,
      false   => 'no',
      true    => 'yes',
      default => $::postfix::resolve_null_domain,
    },
    'resolve_numeric_domain'                                 => $::postfix::resolve_numeric_domain ? {
      undef   => undef,
      false   => 'no',
      true    => 'yes',
      default => $::postfix::resolve_numeric_domain,
    },
    'rewrite_service_name'                                   => $::postfix::rewrite_service_name,
    'sample_directory'                                       => $::postfix::sample_directory,
    'send_cyrus_sasl_authzid'                                => $::postfix::send_cyrus_sasl_authzid ? {
      undef   => undef,
      false   => 'no',
      true    => 'yes',
      default => $::postfix::send_cyrus_sasl_authzid,
    },
    'sender_bcc_maps'                                        => $::postfix::sender_bcc_maps ? {
      undef   => undef,
      default => join($::postfix::sender_bcc_maps, ', '),
    },
    'sender_canonical_classes'                               => $::postfix::sender_canonical_classes ? {
      undef   => undef,
      default => join($::postfix::sender_canonical_classes, ', '),
    },
    'sender_canonical_maps'                                  => $::postfix::sender_canonical_maps ? {
      undef   => undef,
      default => join($::postfix::sender_canonical_maps, ', '),
    },
    'sender_dependent_default_transport_maps'                => $::postfix::sender_dependent_default_transport_maps ? {
      undef   => undef,
      default => join($::postfix::sender_dependent_default_transport_maps, ', '),
    },
    'sender_dependent_relayhost_maps'                        => $::postfix::sender_dependent_relayhost_maps ? {
      undef   => undef,
      default => join($::postfix::sender_dependent_relayhost_maps, ', '),
    },
    'sendmail_fix_line_endings'                              => $::postfix::sendmail_fix_line_endings,
    'sendmail_path'                                          => $::postfix::sendmail_path,
    'service_throttle_time'                                  => $::postfix::service_throttle_time,
    'setgid_group'                                           => $::postfix::setgid_group,
    'show_user_unknown_table_name'                           => $::postfix::show_user_unknown_table_name ? {
      undef   => undef,
      false   => 'no',
      true    => 'yes',
      default => $::postfix::show_user_unknown_table_name,
    },
    'showq_service_name'                                     => $::postfix::showq_service_name,
    'smtp_address_preference'                                => $::postfix::smtp_address_preference,
    'smtp_always_send_ehlo'                                  => $::postfix::smtp_always_send_ehlo ? {
      undef   => undef,
      false   => 'no',
      true    => 'yes',
      default => $::postfix::smtp_always_send_ehlo,
    },
    'smtp_bind_address'                                      => $::postfix::smtp_bind_address,
    'smtp_bind_address6'                                     => $::postfix::smtp_bind_address6,
    'smtp_body_checks'                                       => $::postfix::smtp_body_checks ? {
      undef   => undef,
      default => join($::postfix::smtp_body_checks, ', '),
    },
    'smtp_cname_overrides_servername'                        => $::postfix::smtp_cname_overrides_servername ? {
      undef   => undef,
      false   => 'no',
      true    => 'yes',
      default => $::postfix::smtp_cname_overrides_servername,
    },
    'smtp_connect_timeout'                                   => $::postfix::smtp_connect_timeout,
    'smtp_connection_cache_destinations'                     => $::postfix::smtp_connection_cache_destinations ? {
      undef   => undef,
      default => join($::postfix::smtp_connection_cache_destinations, ', '),
    },
    'smtp_connection_cache_on_demand'                        => $::postfix::smtp_connection_cache_on_demand ? {
      undef   => undef,
      false   => 'no',
      true    => 'yes',
      default => $::postfix::smtp_connection_cache_on_demand,
    },
    'smtp_connection_cache_time_limit'                       => $::postfix::smtp_connection_cache_time_limit,
    'smtp_connection_reuse_time_limit'                       => $::postfix::smtp_connection_reuse_time_limit,
    'smtp_data_done_timeout'                                 => $::postfix::smtp_data_done_timeout,
    'smtp_data_init_timeout'                                 => $::postfix::smtp_data_init_timeout,
    'smtp_data_xfer_timeout'                                 => $::postfix::smtp_data_xfer_timeout,
    'smtp_defer_if_no_mx_address_found'                      => $::postfix::smtp_defer_if_no_mx_address_found ? {
      undef   => undef,
      false   => 'no',
      true    => 'yes',
      default => $::postfix::smtp_defer_if_no_mx_address_found,
    },
    'smtp_discard_ehlo_keyword_address_maps'                 => $::postfix::smtp_discard_ehlo_keyword_address_maps ? {
      undef   => undef,
      default => join($::postfix::smtp_discard_ehlo_keyword_address_maps, ', '),
    },
    'smtp_discard_ehlo_keywords'                             => $::postfix::smtp_discard_ehlo_keywords ? {
      undef   => undef,
      default => join($::postfix::smtp_discard_ehlo_keywords, ', '),
    },
    'smtp_dns_resolver_options'                              => $::postfix::smtp_dns_resolver_options ? {
      undef   => undef,
      default => join($::postfix::smtp_dns_resolver_options, ', '),
    },
    'smtp_enforce_tls'                                       => $::postfix::smtp_enforce_tls ? {
      undef   => undef,
      false   => 'no',
      true    => 'yes',
      default => $::postfix::smtp_enforce_tls,
    },
    'smtp_fallback_relay'                                    => $::postfix::smtp_fallback_relay ? {
      undef   => undef,
      default => join($::postfix::smtp_fallback_relay, ', '),
    },
    'smtp_generic_maps'                                      => $::postfix::smtp_generic_maps ? {
      undef   => undef,
      default => join($::postfix::smtp_generic_maps, ', '),
    },
    'smtp_header_checks'                                     => $::postfix::smtp_header_checks ? {
      undef   => undef,
      default => join($::postfix::smtp_header_checks, ', '),
    },
    'smtp_helo_name'                                         => $::postfix::smtp_helo_name,
    'smtp_helo_timeout'                                      => $::postfix::smtp_helo_timeout,
    'smtp_host_lookup'                                       => $::postfix::smtp_host_lookup ? {
      undef   => undef,
      default => join($::postfix::smtp_host_lookup, ', '),
    },
    'smtp_line_length_limit'                                 => $::postfix::smtp_line_length_limit,
    'smtp_mail_timeout'                                      => $::postfix::smtp_mail_timeout,
    'smtp_mime_header_checks'                                => $::postfix::smtp_mime_header_checks ? {
      undef   => undef,
      default => join($::postfix::smtp_mime_header_checks, ', '),
    },
    'smtp_mx_address_limit'                                  => $::postfix::smtp_mx_address_limit,
    'smtp_mx_session_limit'                                  => $::postfix::smtp_mx_session_limit,
    'smtp_nested_header_checks'                              => $::postfix::smtp_nested_header_checks ? {
      undef   => undef,
      default => join($::postfix::smtp_nested_header_checks, ', '),
    },
    'smtp_never_send_ehlo'                                   => $::postfix::smtp_never_send_ehlo ? {
      undef   => undef,
      false   => 'no',
      true    => 'yes',
      default => $::postfix::smtp_never_send_ehlo,
    },
    'smtp_per_record_deadline'                               => $::postfix::smtp_per_record_deadline ? {
      undef   => undef,
      false   => 'no',
      true    => 'yes',
      default => $::postfix::smtp_per_record_deadline,
    },
    'smtp_pix_workaround_delay_time'                         => $::postfix::smtp_pix_workaround_delay_time,
    'smtp_pix_workaround_maps'                               => $::postfix::smtp_pix_workaround_maps ? {
      undef   => undef,
      default => join($::postfix::smtp_pix_workaround_maps, ', '),
    },
    'smtp_pix_workaround_threshold_time'                     => $::postfix::smtp_pix_workaround_threshold_time,
    'smtp_pix_workarounds'                                   => $::postfix::smtp_pix_workarounds ? {
      undef   => undef,
      default => join($::postfix::smtp_pix_workarounds, ', '),
    },
    'smtp_quit_timeout'                                      => $::postfix::smtp_quit_timeout,
    'smtp_quote_rfc821_envelope'                             => $::postfix::smtp_quote_rfc821_envelope ? {
      undef   => undef,
      false   => 'no',
      true    => 'yes',
      default => $::postfix::smtp_quote_rfc821_envelope,
    },
    'smtp_randomize_addresses'                               => $::postfix::smtp_randomize_addresses ? {
      undef   => undef,
      false   => 'no',
      true    => 'yes',
      default => $::postfix::smtp_randomize_addresses,
    },
    'smtp_rcpt_timeout'                                      => $::postfix::smtp_rcpt_timeout,
    'smtp_reply_filter'                                      => $::postfix::smtp_reply_filter,
    'smtp_rset_timeout'                                      => $::postfix::smtp_rset_timeout,
    'smtp_sasl_auth_cache_name'                              => $::postfix::smtp_sasl_auth_cache_name,
    'smtp_sasl_auth_cache_time'                              => $::postfix::smtp_sasl_auth_cache_time,
    'smtp_sasl_auth_enable'                                  => $::postfix::smtp_sasl_auth_enable ? {
      undef   => undef,
      false   => 'no',
      true    => 'yes',
      default => $::postfix::smtp_sasl_auth_enable,
    },
    'smtp_sasl_auth_soft_bounce'                             => $::postfix::smtp_sasl_auth_soft_bounce ? {
      undef   => undef,
      false   => 'no',
      true    => 'yes',
      default => $::postfix::smtp_sasl_auth_soft_bounce,
    },
    'smtp_sasl_mechanism_filter'                             => $::postfix::smtp_sasl_mechanism_filter ? {
      undef   => undef,
      default => join($::postfix::smtp_sasl_mechanism_filter, ', '),
    },
    'smtp_sasl_password_maps'                                => $::postfix::smtp_sasl_password_maps ? {
      undef   => undef,
      default => join($::postfix::smtp_sasl_password_maps, ', '),
    },
    'smtp_sasl_path'                                         => $::postfix::smtp_sasl_path,
    'smtp_sasl_security_options'                             => $::postfix::smtp_sasl_security_options ? {
      undef   => undef,
      default => join($::postfix::smtp_sasl_security_options, ', '),
    },
    'smtp_sasl_tls_security_options'                         => $::postfix::smtp_sasl_tls_security_options ? {
      undef   => undef,
      default => join($::postfix::smtp_sasl_tls_security_options, ', '),
    },
    'smtp_sasl_tls_verified_security_options'                => $::postfix::smtp_sasl_tls_verified_security_options ? {
      undef   => undef,
      default => join($::postfix::smtp_sasl_tls_verified_security_options, ', '),
    },
    'smtp_sasl_type'                                         => $::postfix::smtp_sasl_type,
    'smtp_send_dummy_mail_auth'                              => $::postfix::smtp_send_dummy_mail_auth ? {
      undef   => undef,
      false   => 'no',
      true    => 'yes',
      default => $::postfix::smtp_send_dummy_mail_auth,
    },
    'smtp_send_xforward_command'                             => $::postfix::smtp_send_xforward_command ? {
      undef   => undef,
      false   => 'no',
      true    => 'yes',
      default => $::postfix::smtp_send_xforward_command,
    },
    'smtp_sender_dependent_authentication'                   => $::postfix::smtp_sender_dependent_authentication ? {
      undef   => undef,
      false   => 'no',
      true    => 'yes',
      default => $::postfix::smtp_sender_dependent_authentication,
    },
    'smtp_skip_5xx_greeting'                                 => $::postfix::smtp_skip_5xx_greeting ? {
      undef   => undef,
      false   => 'no',
      true    => 'yes',
      default => $::postfix::smtp_skip_5xx_greeting,
    },
    'smtp_skip_quit_response'                                => $::postfix::smtp_skip_quit_response ? {
      undef   => undef,
      false   => 'no',
      true    => 'yes',
      default => $::postfix::smtp_skip_quit_response,
    },
    'smtp_starttls_timeout'                                  => $::postfix::smtp_starttls_timeout,
    'smtp_tls_CAfile'                                        => $::postfix::smtp_tls_cafile,
    'smtp_tls_CApath'                                        => $::postfix::smtp_tls_capath,
    'smtp_tls_block_early_mail_reply'                        => $::postfix::smtp_tls_block_early_mail_reply ? {
      undef   => undef,
      false   => 'no',
      true    => 'yes',
      default => $::postfix::smtp_tls_block_early_mail_reply,
    },
    'smtp_tls_cert_file'                                     => $::postfix::smtp_tls_cert_file,
    'smtp_tls_ciphers'                                       => $::postfix::smtp_tls_ciphers,
    'smtp_tls_dcert_file'                                    => $::postfix::smtp_tls_dcert_file,
    'smtp_tls_dkey_file'                                     => $::postfix::smtp_tls_dkey_file,
    'smtp_tls_eccert_file'                                   => $::postfix::smtp_tls_eccert_file,
    'smtp_tls_eckey_file'                                    => $::postfix::smtp_tls_eckey_file,
    'smtp_tls_enforce_peername'                              => $::postfix::smtp_tls_enforce_peername ? {
      undef   => undef,
      false   => 'no',
      true    => 'yes',
      default => $::postfix::smtp_tls_enforce_peername,
    },
    'smtp_tls_exclude_ciphers'                               => $::postfix::smtp_tls_exclude_ciphers ? {
      undef   => undef,
      default => join($::postfix::smtp_tls_exclude_ciphers, ', '),
    },
    'smtp_tls_fingerprint_cert_match'                        => $::postfix::smtp_tls_fingerprint_cert_match ? {
      undef   => undef,
      default => join($::postfix::smtp_tls_fingerprint_cert_match, ', '),
    },
    'smtp_tls_fingerprint_digest'                            => $::postfix::smtp_tls_fingerprint_digest,
    'smtp_tls_key_file'                                      => $::postfix::smtp_tls_key_file,
    'smtp_tls_loglevel'                                      => $::postfix::smtp_tls_loglevel,
    'smtp_tls_mandatory_ciphers'                             => $::postfix::smtp_tls_mandatory_ciphers,
    'smtp_tls_mandatory_exclude_ciphers'                     => $::postfix::smtp_tls_mandatory_exclude_ciphers ? {
      undef   => undef,
      default => join($::postfix::smtp_tls_mandatory_exclude_ciphers, ', '),
    },
    'smtp_tls_mandatory_protocols'                           => $::postfix::smtp_tls_mandatory_protocols ? {
      undef   => undef,
      default => join($::postfix::smtp_tls_mandatory_protocols, ', '),
    },
    'smtp_tls_note_starttls_offer'                           => $::postfix::smtp_tls_note_starttls_offer ? {
      undef   => undef,
      false   => 'no',
      true    => 'yes',
      default => $::postfix::smtp_tls_note_starttls_offer,
    },
    'smtp_tls_per_site'                                      => $::postfix::smtp_tls_per_site ? {
      undef   => undef,
      default => join($::postfix::smtp_tls_per_site, ', '),
    },
    'smtp_tls_policy_maps'                                   => $::postfix::smtp_tls_policy_maps ? {
      undef   => undef,
      default => join($::postfix::smtp_tls_policy_maps, ', '),
    },
    'smtp_tls_protocols'                                     => $::postfix::smtp_tls_protocols ? {
      undef   => undef,
      default => join($::postfix::smtp_tls_protocols, ', '),
    },
    'smtp_tls_scert_verifydepth'                             => $::postfix::smtp_tls_scert_verifydepth,
    'smtp_tls_secure_cert_match'                             => $::postfix::smtp_tls_secure_cert_match ? {
      undef   => undef,
      default => join($::postfix::smtp_tls_secure_cert_match, ', '),
    },
    'smtp_tls_security_level'                                => $::postfix::smtp_tls_security_level,
    'smtp_tls_session_cache_database'                        => $::postfix::smtp_tls_session_cache_database,
    'smtp_tls_session_cache_timeout'                         => $::postfix::smtp_tls_session_cache_timeout,
    'smtp_tls_verify_cert_match'                             => $::postfix::smtp_tls_verify_cert_match ? {
      undef   => undef,
      default => join($::postfix::smtp_tls_verify_cert_match, ', '),
    },
    'smtp_use_tls'                                           => $::postfix::smtp_use_tls ? {
      undef   => undef,
      false   => 'no',
      true    => 'yes',
      default => $::postfix::smtp_use_tls,
    },
    'smtp_xforward_timeout'                                  => $::postfix::smtp_xforward_timeout,
    'smtpd_authorized_verp_clients'                          => $::postfix::smtpd_authorized_verp_clients ? {
      undef   => undef,
      default => join($::postfix::smtpd_authorized_verp_clients, ', '),
    },
    'smtpd_authorized_xclient_hosts'                         => $::postfix::smtpd_authorized_xclient_hosts ? {
      undef   => undef,
      default => join($::postfix::smtpd_authorized_xclient_hosts, ', '),
    },
    'smtpd_authorized_xforward_hosts'                        => $::postfix::smtpd_authorized_xforward_hosts ? {
      undef   => undef,
      default => join($::postfix::smtpd_authorized_xforward_hosts, ', '),
    },
    'smtpd_banner'                                           => $::postfix::smtpd_banner,
    'smtpd_client_connection_count_limit'                    => $::postfix::smtpd_client_connection_count_limit,
    'smtpd_client_connection_rate_limit'                     => $::postfix::smtpd_client_connection_rate_limit,
    'smtpd_client_event_limit_exceptions'                    => $::postfix::smtpd_client_event_limit_exceptions ? {
      undef   => undef,
      default => join($::postfix::smtpd_client_event_limit_exceptions, ', '),
    },
    'smtpd_client_message_rate_limit'                        => $::postfix::smtpd_client_message_rate_limit,
    'smtpd_client_new_tls_session_rate_limit'                => $::postfix::smtpd_client_new_tls_session_rate_limit,
    'smtpd_client_port_logging'                              => $::postfix::smtpd_client_port_logging ? {
      undef   => undef,
      false   => 'no',
      true    => 'yes',
      default => $::postfix::smtpd_client_port_logging,
    },
    'smtpd_client_recipient_rate_limit'                      => $::postfix::smtpd_client_recipient_rate_limit,
    'smtpd_client_restrictions'                              => $::postfix::smtpd_client_restrictions ? {
      undef   => undef,
      default => join($::postfix::smtpd_client_restrictions, ', '),
    },
    'smtpd_command_filter'                                   => $::postfix::smtpd_command_filter,
    'smtpd_data_restrictions'                                => $::postfix::smtpd_data_restrictions ? {
      undef   => undef,
      default => join($::postfix::smtpd_data_restrictions, ', '),
    },
    'smtpd_delay_open_until_valid_rcpt'                      => $::postfix::smtpd_delay_open_until_valid_rcpt ? {
      undef   => undef,
      false   => 'no',
      true    => 'yes',
      default => $::postfix::smtpd_delay_open_until_valid_rcpt,
    },
    'smtpd_delay_reject'                                     => $::postfix::smtpd_delay_reject ? {
      undef   => undef,
      false   => 'no',
      true    => 'yes',
      default => $::postfix::smtpd_delay_reject,
    },
    'smtpd_discard_ehlo_keyword_address_maps'                => $::postfix::smtpd_discard_ehlo_keyword_address_maps ? {
      undef   => undef,
      default => join($::postfix::smtpd_discard_ehlo_keyword_address_maps, ', '),
    },
    'smtpd_discard_ehlo_keywords'                            => $::postfix::smtpd_discard_ehlo_keywords ? {
      undef   => undef,
      default => join($::postfix::smtpd_discard_ehlo_keywords, ', '),
    },
    'smtpd_end_of_data_restrictions'                         => $::postfix::smtpd_end_of_data_restrictions ? {
      undef   => undef,
      default => join($::postfix::smtpd_end_of_data_restrictions, ', '),
    },
    'smtpd_enforce_tls'                                      => $::postfix::smtpd_enforce_tls ? {
      undef   => undef,
      false   => 'no',
      true    => 'yes',
      default => $::postfix::smtpd_enforce_tls,
    },
    'smtpd_error_sleep_time'                                 => $::postfix::smtpd_error_sleep_time,
    'smtpd_etrn_restrictions'                                => $::postfix::smtpd_etrn_restrictions ? {
      undef   => undef,
      default => join($::postfix::smtpd_etrn_restrictions, ', '),
    },
    'smtpd_expansion_filter'                                 => $::postfix::smtpd_expansion_filter,
    'smtpd_forbidden_commands'                               => $::postfix::smtpd_forbidden_commands ? {
      undef   => undef,
      default => join($::postfix::smtpd_forbidden_commands, ', '),
    },
    'smtpd_hard_error_limit'                                 => $::postfix::smtpd_hard_error_limit,
    'smtpd_helo_required'                                    => $::postfix::smtpd_helo_required ? {
      undef   => undef,
      false   => 'no',
      true    => 'yes',
      default => $::postfix::smtpd_helo_required,
    },
    'smtpd_helo_restrictions'                                => $::postfix::smtpd_helo_restrictions ? {
      undef   => undef,
      default => join($::postfix::smtpd_helo_restrictions, ', '),
    },
    'smtpd_history_flush_threshold'                          => $::postfix::smtpd_history_flush_threshold,
    'smtpd_junk_command_limit'                               => $::postfix::smtpd_junk_command_limit,
    'smtpd_log_access_permit_actions'                        => $::postfix::smtpd_log_access_permit_actions,
    'smtpd_milters'                                          => $::postfix::smtpd_milters ? {
      undef   => undef,
      default => join($::postfix::smtpd_milters, ', '),
    },
    'smtpd_noop_commands'                                    => $::postfix::smtpd_noop_commands ? {
      undef   => undef,
      default => join($::postfix::smtpd_noop_commands, ', '),
    },
    'smtpd_null_access_lookup_key'                           => $::postfix::smtpd_null_access_lookup_key,
    'smtpd_peername_lookup'                                  => $::postfix::smtpd_peername_lookup ? {
      undef   => undef,
      false   => 'no',
      true    => 'yes',
      default => $::postfix::smtpd_peername_lookup,
    },
    'smtpd_per_record_deadline'                              => $::postfix::smtpd_per_record_deadline ? {
      undef   => undef,
      false   => 'no',
      true    => 'yes',
      default => $::postfix::smtpd_per_record_deadline,
    },
    'smtpd_policy_service_max_idle'                          => $::postfix::smtpd_policy_service_max_idle,
    'smtpd_policy_service_max_ttl'                           => $::postfix::smtpd_policy_service_max_ttl,
    'smtpd_policy_service_timeout'                           => $::postfix::smtpd_policy_service_timeout,
    'smtpd_proxy_ehlo'                                       => $::postfix::smtpd_proxy_ehlo,
    'smtpd_proxy_filter'                                     => $::postfix::smtpd_proxy_filter,
    'smtpd_proxy_options'                                    => $::postfix::smtpd_proxy_options ? {
      undef   => undef,
      default => join($::postfix::smtpd_proxy_options, ', '),
    },
    'smtpd_proxy_timeout'                                    => $::postfix::smtpd_proxy_timeout,
    'smtpd_recipient_limit'                                  => $::postfix::smtpd_recipient_limit,
    'smtpd_recipient_overshoot_limit'                        => $::postfix::smtpd_recipient_overshoot_limit,
    'smtpd_recipient_restrictions'                           => $::postfix::smtpd_recipient_restrictions ? {
      undef   => undef,
      default => join($::postfix::smtpd_recipient_restrictions, ', '),
    },
    'smtpd_reject_footer'                                    => $::postfix::smtpd_reject_footer,
    'smtpd_reject_unlisted_recipient'                        => $::postfix::smtpd_reject_unlisted_recipient ? {
      undef   => undef,
      false   => 'no',
      true    => 'yes',
      default => $::postfix::smtpd_reject_unlisted_recipient,
    },
    'smtpd_reject_unlisted_sender'                           => $::postfix::smtpd_reject_unlisted_sender ? {
      undef   => undef,
      false   => 'no',
      true    => 'yes',
      default => $::postfix::smtpd_reject_unlisted_sender,
    },
    'smtpd_relay_restrictions'                               => $::postfix::smtpd_relay_restrictions ? {
      undef   => undef,
      default => join($::postfix::smtpd_relay_restrictions, ', '),
    },
    'smtpd_restriction_classes'                              => $::postfix::smtpd_restriction_classes ? {
      undef   => undef,
      default => join($::postfix::smtpd_restriction_classes, ', '),
    },
    'smtpd_sasl_auth_enable'                                 => $::postfix::smtpd_sasl_auth_enable ? {
      undef   => undef,
      false   => 'no',
      true    => 'yes',
      default => $::postfix::smtpd_sasl_auth_enable,
    },
    'smtpd_sasl_authenticated_header'                        => $::postfix::smtpd_sasl_authenticated_header ? {
      undef   => undef,
      false   => 'no',
      true    => 'yes',
      default => $::postfix::smtpd_sasl_authenticated_header,
    },
    'smtpd_sasl_exceptions_networks'                         => $::postfix::smtpd_sasl_exceptions_networks ? {
      undef   => undef,
      default => join($::postfix::smtpd_sasl_exceptions_networks, ', '),
    },
    'smtpd_sasl_local_domain'                                => $::postfix::smtpd_sasl_local_domain,
    'smtpd_sasl_path'                                        => $::postfix::smtpd_sasl_path,
    'smtpd_sasl_security_options'                            => $::postfix::smtpd_sasl_security_options ? {
      undef   => undef,
      default => join($::postfix::smtpd_sasl_security_options, ', '),
    },
    'smtpd_sasl_tls_security_options'                        => $::postfix::smtpd_sasl_tls_security_options ? {
      undef   => undef,
      default => join($::postfix::smtpd_sasl_tls_security_options, ', '),
    },
    'smtpd_sasl_type'                                        => $::postfix::smtpd_sasl_type,
    'smtpd_sender_login_maps'                                => $::postfix::smtpd_sender_login_maps ? {
      undef   => undef,
      default => join($::postfix::smtpd_sender_login_maps, ', '),
    },
    'smtpd_sender_restrictions'                              => $::postfix::smtpd_sender_restrictions ? {
      undef   => undef,
      default => join($::postfix::smtpd_sender_restrictions, ', '),
    },
    'smtpd_service_name'                                     => $::postfix::smtpd_service_name,
    'smtpd_soft_error_limit'                                 => $::postfix::smtpd_soft_error_limit,
    'smtpd_starttls_timeout'                                 => $::postfix::smtpd_starttls_timeout,
    'smtpd_timeout'                                          => $::postfix::smtpd_timeout,
    'smtpd_tls_CAfile'                                       => $::postfix::smtpd_tls_cafile,
    'smtpd_tls_CApath'                                       => $::postfix::smtpd_tls_capath,
    'smtpd_tls_always_issue_session_ids'                     => $::postfix::smtpd_tls_always_issue_session_ids ? {
      undef   => undef,
      false   => 'no',
      true    => 'yes',
      default => $::postfix::smtpd_tls_always_issue_session_ids,
    },
    'smtpd_tls_ask_ccert'                                    => $::postfix::smtpd_tls_ask_ccert ? {
      undef   => undef,
      false   => 'no',
      true    => 'yes',
      default => $::postfix::smtpd_tls_ask_ccert,
    },
    'smtpd_tls_auth_only'                                    => $::postfix::smtpd_tls_auth_only ? {
      undef   => undef,
      false   => 'no',
      true    => 'yes',
      default => $::postfix::smtpd_tls_auth_only,
    },
    'smtpd_tls_ccert_verifydepth'                            => $::postfix::smtpd_tls_ccert_verifydepth,
    'smtpd_tls_cert_file'                                    => $::postfix::smtpd_tls_cert_file,
    'smtpd_tls_ciphers'                                      => $::postfix::smtpd_tls_ciphers,
    'smtpd_tls_dcert_file'                                   => $::postfix::smtpd_tls_dcert_file,
    'smtpd_tls_dh1024_param_file'                            => $::postfix::smtpd_tls_dh1024_param_file,
    'smtpd_tls_dh512_param_file'                             => $::postfix::smtpd_tls_dh512_param_file,
    'smtpd_tls_dkey_file'                                    => $::postfix::smtpd_tls_dkey_file,
    'smtpd_tls_eccert_file'                                  => $::postfix::smtpd_tls_eccert_file,
    'smtpd_tls_eckey_file'                                   => $::postfix::smtpd_tls_eckey_file,
    'smtpd_tls_eecdh_grade'                                  => $::postfix::smtpd_tls_eecdh_grade,
    'smtpd_tls_exclude_ciphers'                              => $::postfix::smtpd_tls_exclude_ciphers ? {
      undef   => undef,
      default => join($::postfix::smtpd_tls_exclude_ciphers, ', '),
    },
    'smtpd_tls_fingerprint_digest'                           => $::postfix::smtpd_tls_fingerprint_digest,
    'smtpd_tls_key_file'                                     => $::postfix::smtpd_tls_key_file,
    'smtpd_tls_loglevel'                                     => $::postfix::smtpd_tls_loglevel,
    'smtpd_tls_mandatory_ciphers'                            => $::postfix::smtpd_tls_mandatory_ciphers,
    'smtpd_tls_mandatory_exclude_ciphers'                    => $::postfix::smtpd_tls_mandatory_exclude_ciphers ? {
      undef   => undef,
      default => join($::postfix::smtpd_tls_mandatory_exclude_ciphers, ', '),
    },
    'smtpd_tls_mandatory_protocols'                          => $::postfix::smtpd_tls_mandatory_protocols ? {
      undef   => undef,
      default => join($::postfix::smtpd_tls_mandatory_protocols, ', '),
    },
    'smtpd_tls_protocols'                                    => $::postfix::smtpd_tls_protocols ? {
      undef   => undef,
      default => join($::postfix::smtpd_tls_protocols, ', '),
    },
    'smtpd_tls_received_header'                              => $::postfix::smtpd_tls_received_header ? {
      undef   => undef,
      false   => 'no',
      true    => 'yes',
      default => $::postfix::smtpd_tls_received_header,
    },
    'smtpd_tls_req_ccert'                                    => $::postfix::smtpd_tls_req_ccert ? {
      undef   => undef,
      false   => 'no',
      true    => 'yes',
      default => $::postfix::smtpd_tls_req_ccert,
    },
    'smtpd_tls_security_level'                               => $::postfix::smtpd_tls_security_level,
    'smtpd_tls_session_cache_database'                       => $::postfix::smtpd_tls_session_cache_database,
    'smtpd_tls_session_cache_timeout'                        => $::postfix::smtpd_tls_session_cache_timeout,
    'smtpd_tls_wrappermode'                                  => $::postfix::smtpd_tls_wrappermode ? {
      undef   => undef,
      false   => 'no',
      true    => 'yes',
      default => $::postfix::smtpd_tls_wrappermode,
    },
    'smtpd_upstream_proxy_protocol'                          => $::postfix::smtpd_upstream_proxy_protocol,
    'smtpd_upstream_proxy_timeout'                           => $::postfix::smtpd_upstream_proxy_timeout,
    'smtpd_use_tls'                                          => $::postfix::smtpd_use_tls ? {
      undef   => undef,
      false   => 'no',
      true    => 'yes',
      default => $::postfix::smtpd_use_tls,
    },
    'soft_bounce'                                            => $::postfix::soft_bounce ? {
      undef   => undef,
      false   => 'no',
      true    => 'yes',
      default => $::postfix::soft_bounce,
    },
    'stale_lock_time'                                        => $::postfix::stale_lock_time,
    'strict_7bit_headers'                                    => $::postfix::strict_7bit_headers ? {
      undef   => undef,
      false   => 'no',
      true    => 'yes',
      default => $::postfix::strict_7bit_headers,
    },
    'strict_8bitmime'                                        => $::postfix::strict_8bitmime ? {
      undef   => undef,
      false   => 'no',
      true    => 'yes',
      default => $::postfix::strict_8bitmime,
    },
    'strict_8bitmime_body'                                   => $::postfix::strict_8bitmime_body ? {
      undef   => undef,
      false   => 'no',
      true    => 'yes',
      default => $::postfix::strict_8bitmime_body,
    },
    'strict_mailbox_ownership'                               => $::postfix::strict_mailbox_ownership ? {
      undef   => undef,
      false   => 'no',
      true    => 'yes',
      default => $::postfix::strict_mailbox_ownership,
    },
    'strict_mime_encoding_domain'                            => $::postfix::strict_mime_encoding_domain ? {
      undef   => undef,
      false   => 'no',
      true    => 'yes',
      default => $::postfix::strict_mime_encoding_domain,
    },
    'strict_rfc821_envelopes'                                => $::postfix::strict_rfc821_envelopes ? {
      undef   => undef,
      false   => 'no',
      true    => 'yes',
      default => $::postfix::strict_rfc821_envelopes,
    },
    'sun_mailtool_compatibility'                             => $::postfix::sun_mailtool_compatibility ? {
      undef   => undef,
      false   => 'no',
      true    => 'yes',
      default => $::postfix::sun_mailtool_compatibility,
    },
    'swap_bangpath'                                          => $::postfix::swap_bangpath ? {
      undef   => undef,
      false   => 'no',
      true    => 'yes',
      default => $::postfix::swap_bangpath,
    },
    'syslog_facility'                                        => $::postfix::syslog_facility,
    'syslog_name'                                            => $::postfix::syslog_name,
    'tcp_windowsize'                                         => $::postfix::tcp_windowsize,
    'tls_append_default_CA'                                  => $::postfix::tls_append_default_ca ? {
      undef   => undef,
      false   => 'no',
      true    => 'yes',
      default => $::postfix::tls_append_default_ca,
    },
    'tls_daemon_random_bytes'                                => $::postfix::tls_daemon_random_bytes,
    'tls_disable_workarounds'                                => $::postfix::tls_disable_workarounds ? {
      undef   => undef,
      default => join($::postfix::tls_disable_workarounds, ', '),
    },
    'tls_eecdh_strong_curve'                                 => $::postfix::tls_eecdh_strong_curve,
    'tls_eecdh_ultra_curve'                                  => $::postfix::tls_eecdh_ultra_curve,
    'tls_export_cipherlist'                                  => $::postfix::tls_export_cipherlist,
    'tls_high_cipherlist'                                    => $::postfix::tls_high_cipherlist,
    'tls_legacy_public_key_fingerprints'                     => $::postfix::tls_legacy_public_key_fingerprints ? {
      undef   => undef,
      false   => 'no',
      true    => 'yes',
      default => $::postfix::tls_legacy_public_key_fingerprints,
    },
    'tls_low_cipherlist'                                     => $::postfix::tls_low_cipherlist,
    'tls_medium_cipherlist'                                  => $::postfix::tls_medium_cipherlist,
    'tls_null_cipherlist'                                    => $::postfix::tls_null_cipherlist,
    'tls_preempt_cipherlist'                                 => $::postfix::tls_preempt_cipherlist ? {
      undef   => undef,
      false   => 'no',
      true    => 'yes',
      default => $::postfix::tls_preempt_cipherlist,
    },
    'tls_random_bytes'                                       => $::postfix::tls_random_bytes,
    'tls_random_exchange_name'                               => $::postfix::tls_random_exchange_name,
    'tls_random_prng_update_period'                          => $::postfix::tls_random_prng_update_period,
    'tls_random_reseed_period'                               => $::postfix::tls_random_reseed_period,
    'tls_random_source'                                      => $::postfix::tls_random_source,
    'tlsproxy_enforce_tls'                                   => $::postfix::tlsproxy_enforce_tls ? {
      undef   => undef,
      false   => 'no',
      true    => 'yes',
      default => $::postfix::tlsproxy_enforce_tls,
    },
    'tlsproxy_service_name'                                  => $::postfix::tlsproxy_service_name,
    'tlsproxy_tls_CAfile'                                    => $::postfix::tlsproxy_tls_cafile,
    'tlsproxy_tls_CApath'                                    => $::postfix::tlsproxy_tls_capath,
    'tlsproxy_tls_always_issue_session_ids'                  => $::postfix::tlsproxy_tls_always_issue_session_ids ? {
      undef   => undef,
      false   => 'no',
      true    => 'yes',
      default => $::postfix::tlsproxy_tls_always_issue_session_ids,
    },
    'tlsproxy_tls_ask_ccert'                                 => $::postfix::tlsproxy_tls_ask_ccert ? {
      undef   => undef,
      false   => 'no',
      true    => 'yes',
      default => $::postfix::tlsproxy_tls_ask_ccert,
    },
    'tlsproxy_tls_ccert_verifydepth'                         => $::postfix::tlsproxy_tls_ccert_verifydepth,
    'tlsproxy_tls_cert_file'                                 => $::postfix::tlsproxy_tls_cert_file,
    'tlsproxy_tls_ciphers'                                   => $::postfix::tlsproxy_tls_ciphers,
    'tlsproxy_tls_dcert_file'                                => $::postfix::tlsproxy_tls_dcert_file,
    'tlsproxy_tls_dh1024_param_file'                         => $::postfix::tlsproxy_tls_dh1024_param_file,
    'tlsproxy_tls_dh512_param_file'                          => $::postfix::tlsproxy_tls_dh512_param_file,
    'tlsproxy_tls_dkey_file'                                 => $::postfix::tlsproxy_tls_dkey_file,
    'tlsproxy_tls_eccert_file'                               => $::postfix::tlsproxy_tls_eccert_file,
    'tlsproxy_tls_eckey_file'                                => $::postfix::tlsproxy_tls_eckey_file,
    'tlsproxy_tls_eecdh_grade'                               => $::postfix::tlsproxy_tls_eecdh_grade,
    'tlsproxy_tls_exclude_ciphers'                           => $::postfix::tlsproxy_tls_exclude_ciphers ? {
      undef   => undef,
      default => join($::postfix::tlsproxy_tls_exclude_ciphers, ', '),
    },
    'tlsproxy_tls_fingerprint_digest'                        => $::postfix::tlsproxy_tls_fingerprint_digest,
    'tlsproxy_tls_key_file'                                  => $::postfix::tlsproxy_tls_key_file,
    'tlsproxy_tls_loglevel'                                  => $::postfix::tlsproxy_tls_loglevel,
    'tlsproxy_tls_mandatory_ciphers'                         => $::postfix::tlsproxy_tls_mandatory_ciphers,
    'tlsproxy_tls_mandatory_exclude_ciphers'                 => $::postfix::tlsproxy_tls_mandatory_exclude_ciphers ? {
      undef   => undef,
      default => join($::postfix::tlsproxy_tls_mandatory_exclude_ciphers, ', '),
    },
    'tlsproxy_tls_mandatory_protocols'                       => $::postfix::tlsproxy_tls_mandatory_protocols ? {
      undef   => undef,
      default => join($::postfix::tlsproxy_tls_mandatory_protocols, ', '),
    },
    'tlsproxy_tls_protocols'                                 => $::postfix::tlsproxy_tls_protocols ? {
      undef   => undef,
      default => join($::postfix::tlsproxy_tls_protocols, ', '),
    },
    'tlsproxy_tls_req_ccert'                                 => $::postfix::tlsproxy_tls_req_ccert ? {
      undef   => undef,
      false   => 'no',
      true    => 'yes',
      default => $::postfix::tlsproxy_tls_req_ccert,
    },
    'tlsproxy_tls_security_level'                            => $::postfix::tlsproxy_tls_security_level,
    'tlsproxy_tls_session_cache_timeout'                     => $::postfix::tlsproxy_tls_session_cache_timeout,
    'tlsproxy_use_tls'                                       => $::postfix::tlsproxy_use_tls ? {
      undef   => undef,
      false   => 'no',
      true    => 'yes',
      default => $::postfix::tlsproxy_use_tls,
    },
    'tlsproxy_watchdog_timeout'                              => $::postfix::tlsproxy_watchdog_timeout,
    'trace_service_name'                                     => $::postfix::trace_service_name,
    'transport_maps'                                         => $::postfix::transport_maps ? {
      undef   => undef,
      default => join($::postfix::transport_maps, ', '),
    },
    'transport_retry_time'                                   => $::postfix::transport_retry_time,
    'trigger_timeout'                                        => $::postfix::trigger_timeout,
    'undisclosed_recipients_header'                          => $::postfix::undisclosed_recipients_header,
    'unknown_address_reject_code'                            => $::postfix::unknown_address_reject_code,
    'unknown_address_tempfail_action'                        => $::postfix::unknown_address_tempfail_action,
    'unknown_client_reject_code'                             => $::postfix::unknown_client_reject_code,
    'unknown_helo_hostname_tempfail_action'                  => $::postfix::unknown_helo_hostname_tempfail_action,
    'unknown_hostname_reject_code'                           => $::postfix::unknown_hostname_reject_code,
    'unknown_local_recipient_reject_code'                    => $::postfix::unknown_local_recipient_reject_code,
    'unknown_relay_recipient_reject_code'                    => $::postfix::unknown_relay_recipient_reject_code,
    'unknown_virtual_alias_reject_code'                      => $::postfix::unknown_virtual_alias_reject_code,
    'unknown_virtual_mailbox_reject_code'                    => $::postfix::unknown_virtual_mailbox_reject_code,
    'unverified_recipient_defer_code'                        => $::postfix::unverified_recipient_defer_code,
    'unverified_recipient_reject_code'                       => $::postfix::unverified_recipient_reject_code,
    'unverified_recipient_reject_reason'                     => $::postfix::unverified_recipient_reject_reason,
    'unverified_recipient_tempfail_action'                   => $::postfix::unverified_recipient_tempfail_action,
    'unverified_sender_defer_code'                           => $::postfix::unverified_sender_defer_code,
    'unverified_sender_reject_code'                          => $::postfix::unverified_sender_reject_code,
    'unverified_sender_reject_reason'                        => $::postfix::unverified_sender_reject_reason,
    'unverified_sender_tempfail_action'                      => $::postfix::unverified_sender_tempfail_action,
    'verp_delimiter_filter'                                  => $::postfix::verp_delimiter_filter,
    'virtual_alias_domains'                                  => $::postfix::virtual_alias_domains ? {
      undef   => undef,
      default => join($::postfix::virtual_alias_domains, ', '),
    },
    'virtual_alias_expansion_limit'                          => $::postfix::virtual_alias_expansion_limit,
    'virtual_alias_maps'                                     => $::postfix::virtual_alias_maps ? {
      undef   => undef,
      default => join($::postfix::virtual_alias_maps, ', '),
    },
    'virtual_alias_recursion_limit'                          => $::postfix::virtual_alias_recursion_limit,
    'virtual_gid_maps'                                       => $::postfix::virtual_gid_maps ? {
      undef   => undef,
      default => join($::postfix::virtual_gid_maps, ', '),
    },
    'virtual_mailbox_base'                                   => $::postfix::virtual_mailbox_base,
    'virtual_mailbox_domains'                                => $::postfix::virtual_mailbox_domains ? {
      undef   => undef,
      default => join($::postfix::virtual_mailbox_domains, ', '),
    },
    'virtual_mailbox_limit'                                  => $::postfix::virtual_mailbox_limit,
    'virtual_mailbox_lock'                                   => $::postfix::virtual_mailbox_lock ? {
      undef   => undef,
      default => join($::postfix::virtual_mailbox_lock, ', '),
    },
    'virtual_mailbox_maps'                                   => $::postfix::virtual_mailbox_maps ? {
      undef   => undef,
      default => join($::postfix::virtual_mailbox_maps, ', '),
    },
    'virtual_minimum_uid'                                    => $::postfix::virtual_minimum_uid,
    'virtual_transport'                                      => $::postfix::virtual_transport,
    'virtual_uid_maps'                                       => $::postfix::virtual_uid_maps,
  })

  $config.each |String $setting, Any $value| {
    postfix_main { $setting:
      value  => $value,
    }
  }

  $::postfix::services.each |$resource, $attributes| {
    postfix_master { $resource:
      * => $attributes,
    }
  }
}
